.. -*- coding: utf-8 -*-

Writing text reports with RestructuredText
==========================================

|cubicweb| offers several text formats for the RichString type used in schemas,
including restructuredtext.

Three additional restructuredtext roles are defined by |cubicweb|:

.. autofunction:: cubicweb.ext.rest.eid_reference_role
.. autofunction:: cubicweb.ext.rest.rql_role
.. autofunction:: cubicweb.ext.rest.bookmark_role
